package com.ruoyi.oa.service.impl;

import java.util.List;
import com.ruoyi.oa.domain.CmcRepair;

/**
 * 维修审批Service接口
 * 
 * @author cmc
 * @date 2026-07-01
 */
public interface ICmcRepairService 
{
    /**
     * 查询维修审批
     * 
     * @param repairId 维修审批主键
     * @return 维修审批
     */
    public CmcRepair selectCmcRepairByRepairId(String repairId);

    /**
     * 查询维修审批列表
     * 
     * @param cmcRepair 维修审批
     * @return 维修审批集合
     */
    public List<CmcRepair> selectCmcRepairList(CmcRepair cmcRepair);

    /**
     * 新增维修审批
     * 
     * @param cmcRepair 维修审批
     * @return 结果
     */
    public int insertCmcRepair(CmcRepair cmcRepair);

    /**
     * 修改维修审批
     * 
     * @param cmcRepair 维修审批
     * @return 结果
     */
    public int updateCmcRepair(CmcRepair cmcRepair);

    /**
     * 批量删除维修审批
     * 
     * @param repairIds 需要删除的维修审批主键集合
     * @return 结果
     */
    public int deleteCmcRepairByRepairIds(String[] repairIds);

    /**
     * 删除维修审批信息
     * 
     * @param repairId 维修审批主键
     * @return 结果
     */
    public int deleteCmcRepairByRepairId(String repairId);

    /**
     * 查询最早申请年份
     * 
     * @return 最早申请年份
     */
    public Integer selectMinApplyYear();
}
